@@ -1,7 +1,9 @@
 package Reflex::Role;
 BEGIN {
-  $Reflex::Role::VERSION = '0.088';
+  $Reflex::Role::VERSION = '0.090';
 }
+# vim: ts=2 sw=2 noexpandtab
+
 use Moose::Role;
 use MooseX::Role::Parameterized;
 use Moose::Exporter;
@@ -13,14 +15,13 @@ use Moose::Exporter;
 
 Moose::Exporter->setup_import_methods(
 	with_caller => [ qw(
-		attribute_parameter method_parameter callback_parameter event_parameter
-		method_emit_and_stop method_emit
+		attribute_parameter method_parameter callback_parameter
 	) ],
 	also => 'MooseX::Role::Parameterized',
 );
 
 sub attribute_parameter {
-	my $caller = shift;
+	my $caller = shift();
 
 	confess "'attribute_parameter' may not be used inside of the role block"
 	if (
@@ -66,63 +67,51 @@ sub method_parameter {
 	);
 }
 
-sub method_emit_and_stop {
-    my $caller = shift;
-    my $meta   = (
-			MooseX::Role::Parameterized::current_metaclass() ||
-			Class::MOP::class_of($caller)
-		);
+# Nearly identical to method_parameter() except it also requires the
+# callback method.
 
-		my ($method_name, $event_name) = @_;
+sub callback_parameter {
+	my $caller = shift;
 
-    my $method = $meta->method_metaclass->wrap(
-        package_name => $caller,
-        name         => $method_name,
-        body         => sub {
-					my ($self, $args) = @_;
-					$self->emit(event => $event_name, args => $args);
-					$self->stopped();
-				},
-    );
+	confess "'method_parameter' may not be used inside of the role block"
+	if (
+		MooseX::Role::Parameterized::current_metaclass() and
+		MooseX::Role::Parameterized::current_metaclass()->genitor->name eq $caller
+	);
 
-    $meta->add_method($method_name => $method);
+	my $meta = Class::MOP::class_of($caller);
+
+	my ($name, $prefix, $member, $suffix) = @_;
+
+	# TODO - $member must have been declared as an attribute_parameter.
+
+	$meta->add_parameter(
+		$name,
+		(
+			isa     => 'Str',
+			lazy    => 1,
+			default => sub {
+				join(
+					"_",
+					grep { defined() and $_ ne "_" }
+					$prefix, shift()->$member(), $suffix
+				)
+			},
+		)
+	);
 }
 
-sub method_emit {
-    my $caller = shift;
-    my $meta   = (
-			MooseX::Role::Parameterized::current_metaclass() ||
-			Class::MOP::class_of($caller)
-		);
-
-		my ($method_name, $event_name) = @_;
-
-    my $method = $meta->method_metaclass->wrap(
-        package_name => $caller,
-        name         => $method_name,
-        body         => sub {
-					my ($self, $args) = @_;
-					$self->emit(event => $event_name, args => $args);
-				},
-    );
-
-    $meta->add_method($method_name => $method);
-}
-
-# Aliased here.
-# TODO - Find out how Moose::Exporter might export method_parameter()
-# as both names.
-#
-# TODO - Default emit methods (method_emit and method_emit_and_stop)
-# are common for callback parameters.  We could include callback
-# parameter flags to automatically generate those methods.
 BEGIN { *callback_parameter = *method_parameter; }
 
-BEGIN { *event_parameter = *method_parameter; }
-
 1;
 
-__END__
+
+
+=pod
+
+=for :stopwords Rocco Caputo
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -130,7 +119,7 @@ Reflex::Role - define a Reflex paramaterized role
 
 =head1 VERSION
 
-version 0.088
+This document describes version 0.090, released on July 30, 2011.
 
 =head1 SYNOPSIS
 
@@ -156,7 +145,7 @@ TODO - Changed again;
 
 		with 'Reflex::Role::Collectible';
 
-		method_emit_and_stop $cb_error => $p->ev_error();
+		method-emit_and_stop $cb_error => $p->ev_error();
 
 		with 'Reflex::Role::Reading' => {
 			handle      => $h,
@@ -278,49 +267,6 @@ equivalent to this MooseX::Role::Parameterized syntax:
 		},
 	);
 
-=head2 METHOD DECLARATIONS
-
-Reflex::Role also provides a couple declarations for standard types of
-methods.
-
-=head3 method_emit
-
-Synopsis:
-
-	method_emit method_name => "event_name";
-
-C<method_emit> defines a method that emits an event, via the emit()
-method provided by Reflex::Role::Reactive.  It's common for default
-Reflex::Role callbacks to emit events, and C<method_emit> will define
-such methods.
-
-C<method_emit> is a convenience declaration.  The synopsis is
-equivalent to this MooseX::Role::Parameterized syntax:
-
-	method method_name => sub {
-		my ($self, $args) = @_;
-		$self->emit( event => "event_name", args => $args );
-	};
-
-=head3 method_emit_and_stopped
-
-Synopsis:
-
-	method_emit_and_stopped method_name => "event_name";
-
-C<method_emit_and_stopped> defines a method that emits an event and
-then triggers the object's eventual distruction.  It takes the names
-of the method to define and the event to emit, and it does the rest.
-
-C<method_emit_and_stopped> is a convenience declaration.  The synopsis
-is equivalent to this MooseX::Role::Parameterized syntax:
-
-	method method_name => sub {
-		my ($self, $args) = @_;
-		$self->emit( event => "event_name", args => $args );
-		$self->stopped();
-	};
-
 =head1 TODO
 
 I'm looking for better names for Reflex::Role's exported declarations.
@@ -332,20 +278,122 @@ Nearly everything in the Reflex::Role namespace.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reflex|Reflex>
+
+=item *
+
 L<Reflex>
+
+=item *
+
 L<Moose>
+
+=item *
+
 L<MooseX::Role::Parameterized>
 
-All the Reflex roles.
+=item *
+
+L<All the Reflex roles.|All the Reflex roles.>
+
+=item *
 
 L<Reflex/ACKNOWLEDGEMENTS>
+
+=item *
+
 L<Reflex/ASSISTANCE>
+
+=item *
+
 L<Reflex/AUTHORS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/CONTRIBUTORS>
+
+=item *
+
 L<Reflex/COPYRIGHT>
+
+=item *
+
 L<Reflex/LICENSE>
+
+=item *
+
 L<Reflex/TODO>
 
-=cut
\ No newline at end of file
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 AUTHOR
+
+Rocco Caputo <rcaputo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Rocco Caputo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/Reflex/>.
+
+The development version lives at L<http://github.com/rcaputo/reflex>
+and may be cloned from L<git://github.com/rcaputo/reflex.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
+
