@@ -1,34 +1,34 @@
 package Reflex::Role::Connecting;
 BEGIN {
-  $Reflex::Role::Connecting::VERSION = '0.088';
+  $Reflex::Role::Connecting::VERSION = '0.090';
 }
+# vim: ts=2 sw=2 noexpandtab
+
 use Reflex::Role;
 
 use Errno qw(EWOULDBLOCK EINPROGRESS);
 use Socket qw(SOL_SOCKET SO_ERROR inet_aton pack_sockaddr_in);
 
-attribute_parameter socket  => "socket";
-attribute_parameter address => "address";
-attribute_parameter port    => "port";
-
-callback_parameter  cb_success  => qw( on socket success );
-callback_parameter  cb_error    => qw( on socket error );
-
-event_parameter     ev_success  => qw( _ socket success );
-event_parameter     ev_error    => qw( _ socket error );
+attribute_parameter att_address => "address";
+attribute_parameter att_port    => "port";
+attribute_parameter att_socket  => "socket";
+callback_parameter  cb_error    => qw( on att_socket error );
+callback_parameter  cb_success  => qw( on att_socket success );
 
 role {
 	my $p = shift;
 
-	my $socket      = $p->socket();
-	my $address     = $p->address();
-	my $port        = $p->port();
+	my $att_address = $p->att_address();
+	my $att_port    = $p->att_port();
+	my $att_socket  = $p->att_socket();
 
-	my $cb_success  = $p->cb_success();
 	my $cb_error    = $p->cb_error();
+	my $cb_success  = $p->cb_success();
 
-	my $internal_writable = "on_" . $socket . "_writable";
-	my $internal_stop     = "stop_" . $socket . "_writable";
+	requires $att_address, $att_port, $att_socket, $cb_error, $cb_success;
+
+	my $internal_writable = "on_${att_socket}_writable";
+	my $internal_stop     = "stop_${att_socket}_writable";
 
 	# Work around a Moose edge case.
 	sub BUILD {}
@@ -43,28 +43,30 @@ role {
 		# make the socket non-blocking if we connect() first.
 
 		# Create a handle if we need to.
-		unless ($self->$socket()) {
-			$self->$socket(IO::Socket::INET->new(Proto => 'tcp'));
+		unless ($self->$att_socket()) {
+			$self->$att_socket(IO::Socket::INET->new(Proto => 'tcp'));
 		}
 
-		my $handle = $self->$socket();
+		my $att_handle = $self->$att_socket();
 
 		my $packed_address;
-		if ($handle->isa("IO::Socket::INET")) {
+		if ($att_handle->isa("IO::Socket::INET")) {
 			# TODO - Need a non-bollocking resolver.
-			my $inet_address = inet_aton($self->$address());
-			$packed_address = pack_sockaddr_in($self->$port(), $inet_address);
+			my $inet_address = inet_aton($self->$att_address());
+			$packed_address = pack_sockaddr_in(
+				$self->$att_port(), $inet_address
+			);
 		}
 		else {
-			die "unknown socket class: ", ref($handle);
+			die "unknown socket class: ", ref($att_handle);
 		}
 
 		# TODO - Make sure we're in the right session.
-		my $method_start = "start_${socket}_writable";
+		my $method_start = "start_${att_socket}_writable";
 		$self->$method_start();
 
 		# Begin connecting.
-		unless (connect($handle, $packed_address)) {
+		unless (connect($att_handle, $packed_address)) {
 			if ($! and ($! != EINPROGRESS) and ($! != EWOULDBLOCK)) {
 				$self->$cb_error(
 					{
@@ -109,17 +111,20 @@ role {
 		return;
 	};
 
-	method_emit $cb_success => $p->ev_success();
-	method_emit $cb_error   => $p->ev_error();
-
 	with 'Reflex::Role::Writable' => {
-		handle  => $socket,
+		att_handle => $att_socket,
 	};
 };
 
 1;
 
-__END__
+
+
+=pod
+
+=for :stopwords Rocco Caputo
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -127,7 +132,7 @@ Reflex::Role::Connecting - add non-blocking client connecting to a class
 
 =head1 VERSION
 
-version 0.088
+This document describes version 0.090, released on July 30, 2011.
 
 =head1 SYNOPSIS
 
@@ -151,7 +156,7 @@ version 0.088
 		isa     => 'Str',
 		default => '127.0.0.1',
 	);
-
+TODO - Changed.
 	with 'Reflex::Role::Connecting' => {
 		connector   => 'socket',      # Default!
 		address     => 'address',     # Default!
@@ -259,19 +264,122 @@ TODO - I'm sure there are some.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reflex|Reflex>
+
+=item *
+
 L<Reflex>
+
+=item *
+
 L<Reflex::Role::Accepting>
+
+=item *
+
 L<Reflex::Acceptor>
+
+=item *
+
 L<Reflex::Connector>
 
+=item *
+
 L<Reflex/ACKNOWLEDGEMENTS>
+
+=item *
+
 L<Reflex/ASSISTANCE>
+
+=item *
+
 L<Reflex/AUTHORS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/CONTRIBUTORS>
+
+=item *
+
 L<Reflex/COPYRIGHT>
+
+=item *
+
 L<Reflex/LICENSE>
+
+=item *
+
 L<Reflex/TODO>
 
-=cut
\ No newline at end of file
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 AUTHOR
+
+Rocco Caputo <rcaputo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Rocco Caputo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/Reflex/>.
+
+The development version lives at L<http://github.com/rcaputo/reflex>
+and may be cloned from L<git://github.com/rcaputo/reflex.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
+
