@@ -1,31 +1,37 @@
 package Reflex::Role::Interval;
 BEGIN {
-  $Reflex::Role::Interval::VERSION = '0.088';
+  $Reflex::Role::Interval::VERSION = '0.090';
 }
+# vim: ts=2 sw=2 noexpandtab
+
 use Reflex::Role;
 use Scalar::Util qw(weaken);
 
-attribute_parameter interval    => "interval";
-attribute_parameter auto_repeat => "auto_repeat";
-attribute_parameter auto_start  => "auto_start";
-
-method_parameter    method_start  => qw( start name _ );
-method_parameter    method_stop   => qw( stop interval _ );
-method_parameter    method_repeat => qw( repeat interval _ );
-
-callback_parameter  cb_tick       => qw( on interval tick );
-event_parameter     ev_tick       => qw( _ interval tick );
+attribute_parameter att_auto_repeat => "auto_repeat";
+attribute_parameter att_auto_start  => "auto_start";
+attribute_parameter att_interval    => "interval";
+callback_parameter  cb_tick         => qw( on att_interval tick );
+method_parameter    method_repeat   => qw( repeat att_interval _ );
+method_parameter    method_start    => qw( start att_interval _ );
+method_parameter    method_stop     => qw( stop att_interval _ );
 
 role {
 	my $p = shift;
 
-	my $interval      = $p->interval();
-	my $timer_id_name = "${interval}_timer_id";
-	my $method_repeat = $p->method_repeat();
-	my $method_stop   = $p->method_stop();
-	my $auto_start    = $p->auto_start();
-	my $auto_repeat   = $p->auto_repeat();
-	my $cb_tick       = $p->cb_tick();
+	my $att_auto_repeat = $p->att_auto_repeat();
+	my $att_auto_start  = $p->att_auto_start();
+	my $att_interval    = $p->att_interval();
+	my $cb_tick         = $p->cb_tick();
+
+	requires $att_interval, $cb_tick;
+
+	has $att_auto_repeat => ( is => 'ro', isa => 'Bool', default => 1 );
+	has $att_auto_start  => ( is => 'ro', isa => 'Bool', default => 1 );
+
+	my $method_repeat   = $p->method_repeat();
+	my $method_stop     = $p->method_stop();
+
+	my $timer_id_name   = "${att_interval}_timer_id";
 
 	has $timer_id_name => (
 		isa => 'Maybe[Str]',
@@ -37,7 +43,7 @@ role {
 
 	after BUILD => sub {
 		my ($self, $args) = @_;
-		$self->$method_repeat() if $self->$auto_start();
+		$self->$method_repeat() if $self->$att_auto_start();
 	};
 
 	method $method_repeat => sub {
@@ -45,7 +51,7 @@ role {
 
 		# Switch to the proper session.
 		return unless (
-			defined $self->$interval() and $self->call_gate($method_repeat)
+			defined $self->$att_interval() and $self->call_gate($method_repeat)
 		);
 
 		# Stop a previous alarm.
@@ -60,7 +66,7 @@ role {
 		$self->$timer_id_name(
 			$POE::Kernel::poe_kernel->delay_set(
 				'timer_due',
-				$self->$interval(),
+				$self->$att_interval(),
 				$envelope,
 			)
 		);
@@ -81,17 +87,21 @@ role {
 		$self->$timer_id_name(undef);
 	};
 
-	my $ev_tick = $p->ev_tick();
-	method $cb_tick => sub {
+	after $cb_tick => sub {
 		my ($self, $args) = @_;
-		$self->emit(event => $ev_tick, args => $args);
-		$self->$method_repeat() if $self->$auto_repeat();
+		$self->$method_repeat() if $self->$att_auto_repeat();
 	};
 };
 
 1;
 
-__END__
+
+
+=pod
+
+=for :stopwords Rocco Caputo
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -99,7 +109,7 @@ Reflex::Role::Interval - set a periodic, recurring timer
 
 =head1 VERSION
 
-version 0.088
+This document describes version 0.090, released on July 30, 2011.
 
 =head1 SYNOPSIS
 
@@ -219,18 +229,118 @@ L<Reflex::Timeout> is one example of using Reflex::Role::Timeout.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reflex|Reflex>
+
+=item *
+
 L<Reflex>
+
+=item *
+
 L<Reflex::Interval>
+
+=item *
+
 L<Reflex::Role>
 
+=item *
+
 L<Reflex/ACKNOWLEDGEMENTS>
+
+=item *
+
 L<Reflex/ASSISTANCE>
+
+=item *
+
 L<Reflex/AUTHORS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/CONTRIBUTORS>
+
+=item *
+
 L<Reflex/COPYRIGHT>
+
+=item *
+
 L<Reflex/LICENSE>
+
+=item *
+
 L<Reflex/TODO>
 
-=cut
\ No newline at end of file
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 AUTHOR
+
+Rocco Caputo <rcaputo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Rocco Caputo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/Reflex/>.
+
+The development version lives at L<http://github.com/rcaputo/reflex>
+and may be cloned from L<git://github.com/rcaputo/reflex.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
+
