@@ -1,37 +1,37 @@
 package Reflex::Role::Reading;
 BEGIN {
-  $Reflex::Role::Reading::VERSION = '0.088';
+  $Reflex::Role::Reading::VERSION = '0.090';
 }
+# vim: ts=2 sw=2 noexpandtab
+
 use Reflex::Role;
 
-attribute_parameter handle    => "handle";
-
-callback_parameter cb_data    => qw( on handle data );
-callback_parameter cb_error   => qw( on handle error );
-callback_parameter cb_closed  => qw( on handle closed );
-
-event_parameter ev_data   => qw( _ handle data );
-event_parameter ev_closed => qw( _ handle closed );
-
-# Matches Reflex::Role::Readable's default callback.
+# The method_read parameter matches Reflex::Role::Readable's default
+# callback.
 # TODO - Any way we can coordinate this so it's obvious in the code
 # but not too verbose?
-method_parameter  method_read => qw( read handle _ );
+
+attribute_parameter att_handle  => "handle";
+callback_parameter  cb_closed   => qw( on att_handle closed );
+callback_parameter  cb_data     => qw( on att_handle data );
+callback_parameter  cb_error    => qw( on att_handle error );
+method_parameter    method_read => qw( read att_handle _ );
 
 role {
 	my $p = shift;
 
-	my $h           = $p->handle();
+	my $att_handle  = $p->att_handle();
+	my $cb_closed   = $p->cb_closed();
 	my $cb_data     = $p->cb_data();
 	my $cb_error    = $p->cb_error();
-	my $cb_closed   = $p->cb_closed();
 	my $method_read = $p->method_read();
 
-	requires $cb_error;
+	requires $att_handle, $cb_closed, $cb_data, $cb_error;
 
 	method $method_read => sub {
 		my ($self, $arg) = @_;
 
+		# TODO - Hardcoding this at 65536 isn't very flexible.
 		my $octet_count = sysread($arg->{handle}, my $buffer = "", 65536);
 
 		# Got data.
@@ -56,23 +56,17 @@ role {
 		);
 		return; # Nothing.
 	};
-
-	# Default callbacks that re-emit their parameters.
-
-	method_emit           $cb_data    => $p->ev_data();
-	method_emit_and_stop  $cb_closed  => $p->ev_closed();
-
-#	my $ev_closed = $p->ev_closed();
-#	method $cb_closed => sub {
-#		my ($self, $args) = @_;
-#		$self->emit(event => $ev_closed, args => $args);
-#		$self->stopped();
-#	};
 };
 
 1;
 
-__END__
+
+
+=pod
+
+=for :stopwords Rocco Caputo
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -80,7 +74,7 @@ Reflex::Role::Reading - add standard sysread() behavior to a class
 
 =head1 VERSION
 
-version 0.088
+This document describes version 0.090, released on July 30, 2011.
 
 =head1 SYNOPSIS
 
@@ -102,8 +96,8 @@ TODO - Changed again.
 		my $cb_error    = $p->cb_error();
 		my $method_read = "on_${h}_readable";
 
-		method_emit_and_stop $cb_error => $p->ev_error();
-
+		method-emit_and_stop $cb_error => $p->ev_error();
+TODO - Changed.
 		with 'Reflex::Role::Reading' => {
 			handle      => $h,
 			cb_data     => $p->cb_data(),
@@ -225,20 +219,126 @@ TODO - I'm sure there are some.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reflex|Reflex>
+
+=item *
+
 L<Reflex>
+
+=item *
+
 L<Reflex::Role>
+
+=item *
+
 L<Reflex::Role::Writing>
+
+=item *
+
 L<Reflex::Role::Readable>
+
+=item *
+
 L<Reflex::Role::Streaming>
 
+=item *
+
 L<Reflex/ACKNOWLEDGEMENTS>
+
+=item *
+
 L<Reflex/ASSISTANCE>
+
+=item *
+
 L<Reflex/AUTHORS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/CONTRIBUTORS>
+
+=item *
+
 L<Reflex/COPYRIGHT>
+
+=item *
+
 L<Reflex/LICENSE>
+
+=item *
+
 L<Reflex/TODO>
 
-=cut
\ No newline at end of file
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 AUTHOR
+
+Rocco Caputo <rcaputo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Rocco Caputo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/Reflex/>.
+
+The development version lives at L<http://github.com/rcaputo/reflex>
+and may be cloned from L<git://github.com/rcaputo/reflex.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
+
