@@ -1,20 +1,19 @@
 package Reflex::Role::Recving;
 BEGIN {
-  $Reflex::Role::Recving::VERSION = '0.088';
+  $Reflex::Role::Recving::VERSION = '0.090';
 }
+# vim: ts=2 sw=2 noexpandtab
+
 use Reflex::Role;
 
-attribute_parameter handle => "socket";
-
-callback_parameter  cb_datagram => qw( on handle datagram );
-callback_parameter  cb_error    => qw( on handle error );
-
-callback_parameter  ev_datagram => qw( _ handle datagram );
-callback_parameter  ev_error    => qw( _ handle error );
-
-method_parameter    method_send => qw( send handle _ );
-method_parameter    method_stop => qw( stop handle _ );
+attribute_parameter att_active  => "active";
+attribute_parameter att_handle  => "socket";
+callback_parameter  cb_datagram => qw( on att_handle datagram );
+callback_parameter  cb_error    => qw( on att_handle error );
+method_parameter    method_send => qw( send att_handle _ );
+method_parameter    method_stop => qw( stop att_handle _ );
 
+# TODO - attribute_parameter?
 parameter max_datagram_size => (
 	isa     => 'Int',
 	is      => 'rw',
@@ -24,18 +23,21 @@ parameter max_datagram_size => (
 role {
 	my $p = shift;
 
-	my $h           = $p->handle();
+	my $att_active  = $p->att_active();
+	my $att_handle  = $p->att_handle();
 	my $cb_datagram = $p->cb_datagram();
 	my $cb_error    = $p->cb_error();
 	my $max_dg_size = $p->max_datagram_size();
 
+	requires $att_active, $att_handle, $cb_datagram, $cb_error;
+
 	method $p->method_stop() => sub {
 		my $self = shift;
-		my $method = "stop_${h}_readable";
+		my $method = "stop_${att_handle}_readable";
 		$self->$method();
 	};
 
-	method "on_${h}_readable" => sub {
+	method "on_${att_handle}_readable" => sub {
 		my ($self, $args) = @_;
 
 		my $remote_address = recv(
@@ -75,7 +77,7 @@ role {
 
 		# Success!
 		return if send(
-			$self->$h,
+			$self->$att_handle,
 			$args->{datagram},
 			0,
 			$args->{remote_addr},
@@ -91,23 +93,20 @@ role {
 	};
 
 	with 'Reflex::Role::Readable' => {
-		handle => $h,
+		att_active => $att_active,
+		att_handle => $att_handle,
 	};
-
-	# Default callbacks that re-emit their parameters.
-	method_emit           $cb_datagram  => $p->ev_datagram();
-	method_emit_and_stop  $cb_error     => $p->ev_error();
 };
 
 1;
 
-__END__
 
 
+=pod
 
-1;
+=for :stopwords Rocco Caputo
 
-__END__
+=encoding UTF-8
 
 =head1 NAME
 
@@ -115,7 +114,7 @@ Reflex::Role::Recving - Mix standard send/recv code into a class.
 
 =head1 VERSION
 
-version 0.088
+This document describes version 0.090, released on July 30, 2011.
 
 =head1 SYNOPSIS
 
@@ -238,20 +237,128 @@ eg/eg-06-moose-roles.pl composes an ojbect with Reflex::Role::UdpPeer.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reflex|Reflex>
+
+=item *
+
 L<Moose::Manual::Concepts>
 
+=item *
+
 L<Reflex>
+
+=item *
+
 L<Reflex::Base>
+
+=item *
+
 L<Reflex::UdpPeer>
 
+=item *
+
 L<Reflex/ACKNOWLEDGEMENTS>
+
+=item *
+
 L<Reflex/ASSISTANCE>
+
+=item *
+
 L<Reflex/AUTHORS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/CONTRIBUTORS>
+
+=item *
+
 L<Reflex/COPYRIGHT>
+
+=item *
+
 L<Reflex/LICENSE>
+
+=item *
+
 L<Reflex/TODO>
 
-=cut
\ No newline at end of file
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 AUTHOR
+
+Rocco Caputo <rcaputo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Rocco Caputo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/Reflex/>.
+
+The development version lives at L<http://github.com/rcaputo/reflex>
+and may be cloned from L<git://github.com/rcaputo/reflex.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
+
+
+
+1;
+
+__END__
+
