@@ -1,24 +1,20 @@
 package Reflex::Role::SigCatcher;
 BEGIN {
-  $Reflex::Role::SigCatcher::VERSION = '0.088';
+  $Reflex::Role::SigCatcher::VERSION = '0.090';
 }
+# vim: ts=2 sw=2 noexpandtab
+
 use Reflex::Role;
 
 use Scalar::Util qw(weaken);
 
-attribute_parameter signal => "signal";
-
-parameter active => (
-	isa       => 'Str',
-	default   => 'active',
-);
-
-callback_parameter  cb_signal     => qw( on signal caught );
-event_parameter     ev_signal     => qw( _ signal caught );
-method_parameter    method_start  => qw( start signal _ );
-method_parameter    method_stop   => qw( stop signal _ );
-method_parameter    method_pause  => qw( pause signal _ );
-method_parameter    method_resume => qw( resume signal _ );
+attribute_parameter att_active    => "active";
+attribute_parameter att_signal    => "signal";
+callback_parameter  cb_signal     => qw( on att_signal caught );
+method_parameter    method_pause  => qw( pause att_signal _ );
+method_parameter    method_resume => qw( resume att_signal _ );
+method_parameter    method_start  => qw( start att_signal _ );
+method_parameter    method_stop   => qw( stop att_signal _ );
 
 # A session may only watch a distinct signal once.
 # So we must map each distinct signal to all the interested objects.
@@ -70,10 +66,12 @@ sub deliver {
 role {
 	my $p = shift;
 
-	my $signal        = $p->signal();
-	my $active        = $p->active();
+	my $att_signal    = $p->att_signal();
+	my $att_active    = $p->att_active();
 	my $cb_signal     = $p->cb_signal();
 
+	requires $att_signal, $att_active, $cb_signal;
+
 	my $method_start  = $p->method_start();
 	my $method_stop   = $p->method_stop();
 	my $method_pause  = $p->method_pause();
@@ -83,7 +81,7 @@ role {
 	sub BUILD {}
 
 	after BUILD => sub {
-		return unless $active;
+		return unless $att_active;
 		shift()->$method_start();
 		return;
 	};
@@ -98,7 +96,7 @@ role {
 	method $method_start => sub {
 		my $self = shift;
 
-		my $sig_name = $self->$signal();
+		my $sig_name = $self->$att_signal();
 
 		# Register this object with that signal.
 		$callbacks{$sig_name}->{$self->session_id()}->{$self} = [
@@ -122,7 +120,12 @@ role {
 		# Be in the session associated with this object.
 		return unless $self->call_gate($method_pause);
 
-		$POE::Kernel::poe_kernel->sig($self->$signal(), undef);
+		$POE::Kernel::poe_kernel->refcount_decrement(
+			$self->session_id(),
+			"signals_keep_alive"
+		);
+
+		$POE::Kernel::poe_kernel->sig($self->$att_signal(), undef);
 	};
 
 	method $method_resume => sub {
@@ -131,15 +134,20 @@ role {
 		# Be in the session associated with this object.
 		return unless $self->call_gate($method_resume);
 
+		$POE::Kernel::poe_kernel->refcount_increment(
+			$self->session_id(),
+			"signals_keep_alive"
+		);
+
 		$POE::Kernel::poe_kernel->sig(
-			$self->$signal(), "signal_happened", ref($self)
+			$self->$att_signal(), "signal_happened", ref($self)
 		);
 	};
 
 	method $method_stop => sub {
 		my $self = shift;
 
-		my $sig_name = $self->$signal();
+		my $sig_name = $self->$att_signal();
 
 		# Nothing to do?
 		return unless exists $callbacks{$sig_name}->{$self->session_id()};
@@ -155,11 +163,15 @@ role {
 			$self->$method_pause();
 		}
 	};
-
-	method_emit $cb_signal => $p->ev_signal();
 };
 
-__END__
+
+
+=pod
+
+=for :stopwords Rocco Caputo
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -167,7 +179,7 @@ Reflex::Role::SigCatcher - add signal catching behavior to a class
 
 =head1 VERSION
 
-version 0.088
+This document describes version 0.090, released on July 30, 2011.
 
 =head1 SYNOPSIS
 
@@ -187,7 +199,7 @@ version 0.088
 		isa     => 'Bool',
 		default => 1,
 	);
-
+TODO - Changed.
 	with 'Reflex::Role::SigCatcher' => {
 		signal        => 'signal',
 		active        => 'active',
@@ -290,19 +302,122 @@ Reflex::Role::SigCatcher.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reflex|Reflex>
+
+=item *
+
 L<Reflex>
+
+=item *
+
 L<Reflex::Signal>
+
+=item *
+
 L<Reflex::Role::PidCatcher>
+
+=item *
+
 L<Reflex::PID>
 
+=item *
+
 L<Reflex/ACKNOWLEDGEMENTS>
+
+=item *
+
 L<Reflex/ASSISTANCE>
+
+=item *
+
 L<Reflex/AUTHORS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/CONTRIBUTORS>
+
+=item *
+
 L<Reflex/COPYRIGHT>
+
+=item *
+
 L<Reflex/LICENSE>
+
+=item *
+
 L<Reflex/TODO>
 
-=cut
\ No newline at end of file
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 AUTHOR
+
+Rocco Caputo <rcaputo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Rocco Caputo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/Reflex/>.
+
+The development version lives at L<http://github.com/rcaputo/reflex>
+and may be cloned from L<git://github.com/rcaputo/reflex.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
+
