@@ -1,61 +1,60 @@
 package Reflex::Role::Streaming;
 BEGIN {
-  $Reflex::Role::Streaming::VERSION = '0.088';
+  $Reflex::Role::Streaming::VERSION = '0.090';
 }
+# vim: ts=2 sw=2 noexpandtab
+
 use Reflex::Role;
 
-attribute_parameter handle      => "handle";
-callback_parameter  cb_data     => qw( on handle data );
-callback_parameter  cb_error    => qw( on handle error );
-callback_parameter  cb_closed   => qw( on handle closed );
-method_parameter    method_put  => qw( put handle _ );
-method_parameter    method_stop => qw( stop handle _ );
-
-event_parameter     ev_data     => qw( _ handle data );
-event_parameter     ev_error    => qw( _ handle error );
-event_parameter     ev_closed   => qw( _ handle closed );
+attribute_parameter att_active  => "active";
+attribute_parameter att_handle  => "handle";
+callback_parameter  cb_closed   => qw( on att_handle closed );
+callback_parameter  cb_data     => qw( on att_handle data );
+callback_parameter  cb_error    => qw( on att_handle error );
+method_parameter    method_put  => qw( put att_handle _ );
+method_parameter    method_stop => qw( stop att_handle _ );
 
 role {
 	my $p = shift;
 
-	my $h           = $p->handle();
+	my $att_active  = $p->att_active();
+	my $att_handle  = $p->att_handle();
 	my $cb_error    = $p->cb_error();
-	my $ev_error    = $p->ev_error();
-	my $method_read = "_on_${h}_readable";
+
+	requires $att_handle, $p->cb_closed(), $p->cb_data(), $cb_error;
+
 	my $method_put  = $p->method_put();
 
-	my $method_writable = "_on_${h}_writable";
-	my $internal_flush  = "_do_${h}_flush";
-	my $internal_put    = "_do_${h}_put";
-	my $pause_writable  = "_pause_${h}_writable";
-	my $resume_writable = "_resume_${h}_writable";
+	my $internal_flush       = "_do_${att_handle}_flush";
+	my $internal_put         = "_do_${att_handle}_put";
+	my $method_read          = "_on_${att_handle}_readable";
+	my $method_writable      = "_on_${att_handle}_writable";
+	my $pause_writable       = "_pause_${att_handle}_writable";
+	my $resume_writable      = "_resume_${att_handle}_writable";
+	my $stop_handle_readable = "stop_${att_handle}_readable";
+	my $stop_handle_writable = "stop_${att_handle}_writable";
 
 	with 'Reflex::Role::Collectible';
 
-	method_emit_and_stop $cb_error => $ev_error;
-
 	with 'Reflex::Role::Reading' => {
-		handle      => $h,
+		att_handle  => $att_handle,
 		cb_data     => $p->cb_data(),
-		ev_data     => $p->ev_data(),
 		cb_error    => $cb_error,
-		ev_error    => $ev_error,
 		cb_closed   => $p->cb_closed(),
-		ev_closed   => $p->ev_closed(),
 		method_read => $method_read,
 	};
 
 	with 'Reflex::Role::Readable' => {
-		handle      => $h,
-		active      => 1,
+		att_handle  => $att_handle,
+		att_active  => $att_active,
 		cb_ready    => $method_read,
 	};
 
 	with 'Reflex::Role::Writing' => {
-		handle      => $h,
-		cb_error    => $cb_error,
-		ev_error    => $ev_error,
-		method_put  => $internal_put,
+		att_handle   => $att_handle,
+		cb_error     => $cb_error,
+		method_put   => $internal_put,
+		method_flush => $internal_flush,
 	};
 
 	method $method_writable => sub {
@@ -68,16 +67,16 @@ role {
 	};
 
 	with 'Reflex::Role::Writable' => {
-		handle      => $h,
-		cb_ready    => $method_writable,
+		att_handle   => $att_handle,
+		cb_ready     => $method_writable,
 		method_pause => $pause_writable,
 	};
 
 	# Multiplex a single stop() to the sub-roles.
 	method $p->method_stop() => sub {
 		my $self = shift;
-		$self->stop_handle_readable();
-		$self->stop_handle_writable();
+		$self->$stop_handle_readable();
+		$self->$stop_handle_writable();
 	};
 
 	method $method_put => sub {
@@ -91,7 +90,13 @@ role {
 
 1;
 
-__END__
+
+
+=pod
+
+=for :stopwords Rocco Caputo
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -99,7 +104,7 @@ Reflex::Role::Streaming - add streaming I/O behavior to a class
 
 =head1 VERSION
 
-version 0.088
+This document describes version 0.090, released on July 30, 2011.
 
 =head1 SYNOPSIS
 
@@ -207,19 +212,122 @@ TODO - I'm sure there are some.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reflex|Reflex>
+
+=item *
+
 L<Reflex>
+
+=item *
+
 L<Reflex::Role::Readable>
+
+=item *
+
 L<Reflex::Role::Writable>
+
+=item *
+
 L<Reflex::Stream>
 
+=item *
+
 L<Reflex/ACKNOWLEDGEMENTS>
+
+=item *
+
 L<Reflex/ASSISTANCE>
+
+=item *
+
 L<Reflex/AUTHORS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/CONTRIBUTORS>
+
+=item *
+
 L<Reflex/COPYRIGHT>
+
+=item *
+
 L<Reflex/LICENSE>
+
+=item *
+
 L<Reflex/TODO>
 
-=cut
\ No newline at end of file
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 AUTHOR
+
+Rocco Caputo <rcaputo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Rocco Caputo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/Reflex/>.
+
+The development version lives at L<http://github.com/rcaputo/reflex>
+and may be cloned from L<git://github.com/rcaputo/reflex.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
+
