@@ -1,26 +1,29 @@
 package Reflex::Role::Wakeup;
 BEGIN {
-  $Reflex::Role::Wakeup::VERSION = '0.088';
+  $Reflex::Role::Wakeup::VERSION = '0.090';
 }
+# vim: ts=2 sw=2 noexpandtab
+
 use Reflex::Role;
 use Scalar::Util qw(weaken);
 
-attribute_parameter when          => "when";
-
-method_parameter    method_stop   => qw( stop when _ );
-method_parameter    method_reset  => qw( reset when _ );
-callback_parameter  cb_wakeup     => qw( on when wakeup );
+attribute_parameter att_when      => "when";
+callback_parameter  cb_wakeup     => qw( on att_when wakeup );
+method_parameter    method_reset  => qw( reset att_when _ );
+method_parameter    method_stop   => qw( stop att_when _ );
 
 role {
 	my $p = shift;
 
-	my $when          = $p->when();
+	my $att_when      = $p->att_when();
+	my $cb_wakeup     = $p->cb_wakeup();
 
-	my $timer_id_name = "${when}_timer_id";
+	requires $att_when, $cb_wakeup;
 
 	my $method_reset  = $p->method_reset();
 	my $method_stop   = $p->method_stop();
-	my $cb_wakeup     = $p->cb_wakeup();
+
+	my $timer_id_name = "${att_when}_timer_id";
 
 	has $timer_id_name => (
 		isa => 'Maybe[Str]',
@@ -32,7 +35,7 @@ role {
 
 	after BUILD => sub {
 		my ($self, $args) = @_;
-		$self->$method_reset( { when => $self->$when() } );
+		$self->$method_reset( { when => $self->$att_when() } );
 	};
 
 	method $method_reset => sub {
@@ -40,11 +43,11 @@ role {
 
 		# Switch to the proper session.
 		return unless (
-			defined $self->$when() and $self->call_gate($method_reset)
+			defined $self->$att_when() and $self->call_gate($method_reset)
 		);
 
 		# If the args include "when", then let's reset when().
-		$self->$when( $args->{when} ) if exists $args->{when};
+		$self->$att_when( $args->{when} ) if exists $args->{when};
 
 		# Stop a previous alarm.
 		$self->$method_stop() if defined $self->$timer_id_name();
@@ -58,7 +61,7 @@ role {
 		$self->$timer_id_name(
 			$POE::Kernel::poe_kernel->alarm_set(
 				'timer_due',
-				$self->$when(),
+				$self->$att_when(),
 				$envelope,
 			)
 		);
@@ -79,16 +82,20 @@ role {
 		$self->$timer_id_name(undef);
 	};
 
-	method $cb_wakeup => sub {
-		my ($self, $args) = @_;
-		$self->emit(event => "time", args => $args);
-		$self->$method_stop();
+	after $cb_wakeup => sub {
+		shift()->$method_stop();
 	};
 };
 
 1;
 
-__END__
+
+
+=pod
+
+=for :stopwords Rocco Caputo
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -96,7 +103,7 @@ Reflex::Role::Wakeup - set a wakeup callback for a particular UNIX time
 
 =head1 VERSION
 
-version 0.088
+This document describes version 0.090, released on July 30, 2011.
 
 =head1 SYNOPSIS
 
@@ -196,18 +203,118 @@ L<Reflex::Wakeup> is one example of using Reflex::Role::Wakeup.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reflex|Reflex>
+
+=item *
+
 L<Reflex>
+
+=item *
+
 L<Reflex::Wakeup>
+
+=item *
+
 L<Reflex::Role>
 
+=item *
+
 L<Reflex/ACKNOWLEDGEMENTS>
+
+=item *
+
 L<Reflex/ASSISTANCE>
+
+=item *
+
 L<Reflex/AUTHORS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/CONTRIBUTORS>
+
+=item *
+
 L<Reflex/COPYRIGHT>
+
+=item *
+
 L<Reflex/LICENSE>
+
+=item *
+
 L<Reflex/TODO>
 
-=cut
\ No newline at end of file
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 AUTHOR
+
+Rocco Caputo <rcaputo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Rocco Caputo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/Reflex/>.
+
+The development version lives at L<http://github.com/rcaputo/reflex>
+and may be cloned from L<git://github.com/rcaputo/reflex.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
+
