@@ -1,7 +1,9 @@
 package Reflex::Role::Writable;
 BEGIN {
-  $Reflex::Role::Writable::VERSION = '0.088';
+  $Reflex::Role::Writable::VERSION = '0.090';
 }
+# vim: ts=2 sw=2 noexpandtab
+
 use Reflex::Role;
 
 # TODO - Reflex::Role::Readable and Writable are nearly identical.
@@ -10,32 +12,27 @@ use Reflex::Role;
 
 use Scalar::Util qw(weaken);
 
-attribute_parameter handle => "handle";
-
-parameter active => (
-	isa     => 'Bool',
-	default => 0,
-);
-
-callback_parameter  cb_ready      => qw( on handle writable );
-method_parameter    method_pause  => qw( pause handle writable );
-method_parameter    method_resume => qw( resume handle writable );
-method_parameter    method_stop   => qw( stop handle writable );
-method_parameter    method_start  => qw( start handle writable );
+attribute_parameter att_active    => "active";
+attribute_parameter att_handle    => "handle";
+callback_parameter  cb_ready      => qw( on att_handle writable );
+method_parameter    method_pause  => qw( pause att_handle writable );
+method_parameter    method_resume => qw( resume att_handle writable );
+method_parameter    method_start  => qw( start att_handle writable );
+method_parameter    method_stop   => qw( stop att_handle writable );
 
 role {
 	my $p = shift;
 
-	my $h             = $p->handle();
-	my $active        = $p->active();
-
+	my $att_active    = $p->att_active();
+	my $att_handle    = $p->att_handle();
 	my $cb_name       = $p->cb_ready();
-	my $method_start  = $p->method_start();
-	my $method_stop   = $p->method_stop();
+
+	requires $att_active, $att_handle, $cb_name;
+
 	my $method_pause  = $p->method_pause();
 	my $method_resume = $p->method_resume();
-
-	requires $cb_name;
+	my $method_start  = $p->method_start();
+	my $method_stop   = $p->method_stop();
 
 	method $method_start => sub {
 		my ($self, $arg) = @_;
@@ -46,26 +43,26 @@ role {
 		my $envelope = [ $self, $cb_name ];
 		weaken $envelope->[0];
 		$POE::Kernel::poe_kernel->select_write(
-			$self->$h(), 'select_ready', $envelope,
+			$self->$att_handle(), 'select_ready', $envelope,
 		);
 	};
 
 	method $method_pause => sub {
 		my ($self, $arg) = @_;
 		return unless $self->call_gate($method_pause, $arg);
-		$POE::Kernel::poe_kernel->select_pause_write($self->$h());
+		$POE::Kernel::poe_kernel->select_pause_write($self->$att_handle());
 	};
 
 	method $method_resume => sub {
 		my ($self, $arg) = @_;
 		return unless $self->call_gate($method_resume, $arg);
-		$POE::Kernel::poe_kernel->select_resume_write($self->$h());
+		$POE::Kernel::poe_kernel->select_resume_write($self->$att_handle());
 	};
 
 	method $method_stop => sub {
 		my ($self, $arg) = @_;
 		return unless $self->call_gate($method_stop, $arg);
-		$POE::Kernel::poe_kernel->select_write($self->$h(), undef);
+		$POE::Kernel::poe_kernel->select_write($self->$att_handle(), undef);
 	};
 
 	# Work around a Moose edge case.
@@ -73,7 +70,7 @@ role {
 
 	after BUILD => sub {
 		my ($self, $arg) = @_;
-		$self->$method_start() if $active;
+		$self->$method_start() if $self->$att_active();
 	};
 
 	# Work around a Moose edge case.
@@ -88,7 +85,13 @@ role {
 
 1;
 
-__END__
+
+
+=pod
+
+=for :stopwords Rocco Caputo
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -96,7 +99,7 @@ Reflex::Role::Writable - add writable-watching behavior to a class
 
 =head1 VERSION
 
-version 0.088
+This document describes version 0.090, released on July 30, 2011.
 
 =head1 SYNOPSIS
 
@@ -197,18 +200,118 @@ TODO - I'm sure there are some.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reflex|Reflex>
+
+=item *
+
 L<Reflex>
+
+=item *
+
 L<Reflex::Role::Readable>
+
+=item *
+
 L<Reflex::Role::Streaming>
 
+=item *
+
 L<Reflex/ACKNOWLEDGEMENTS>
+
+=item *
+
 L<Reflex/ASSISTANCE>
+
+=item *
+
 L<Reflex/AUTHORS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/CONTRIBUTORS>
+
+=item *
+
 L<Reflex/COPYRIGHT>
+
+=item *
+
 L<Reflex/LICENSE>
+
+=item *
+
 L<Reflex/TODO>
 
-=cut
\ No newline at end of file
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 AUTHOR
+
+Rocco Caputo <rcaputo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Rocco Caputo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/Reflex/>.
+
+The development version lives at L<http://github.com/rcaputo/reflex>
+and may be cloned from L<git://github.com/rcaputo/reflex.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
+
