@@ -1,22 +1,25 @@
 package Reflex::Role::Writing;
 BEGIN {
-  $Reflex::Role::Writing::VERSION = '0.088';
+  $Reflex::Role::Writing::VERSION = '0.090';
 }
+# vim: ts=2 sw=2 noexpandtab
+
 use Reflex::Role;
 
-attribute_parameter handle        => "handle";
-method_parameter    method_put    => qw( put handle _ );
-method_parameter    method_flush  => qw( flush handle _ );
-callback_parameter  cb_error      => qw( on handle error );
+attribute_parameter att_handle    => "handle";
+callback_parameter  cb_error      => qw( on att_handle error );
+method_parameter    method_flush  => qw( flush att_handle _ );
+method_parameter    method_put    => qw( put att_handle _ );
 
 role {
 	my $p = shift;
 
-	my $h             = $p->handle();
+	my $att_handle    = $p->att_handle();
 	my $cb_error      = $p->cb_error();
-	my $method_flush  = $p->method_flush();
 
-	requires $cb_error;
+	requires $att_handle, $cb_error;
+
+	my $method_flush  = $p->method_flush();
 
 	has out_buffer => (
 		is      => 'rw',
@@ -28,7 +31,7 @@ role {
 		my ($self, $arg) = @_;
 
 		my $out_buffer = $self->out_buffer();
-		my $octet_count = syswrite($self->$h(), $$out_buffer);
+		my $octet_count = syswrite($self->$att_handle(), $$out_buffer);
 
 		# Hard error.
 		unless (defined $octet_count) {
@@ -69,7 +72,7 @@ role {
 		# Try to flush 'em all.
 		while (@chunks) {
 			my $next = shift @chunks;
-			my $octet_count = syswrite($self->$h(), $next);
+			my $octet_count = syswrite($self->$att_handle(), $next);
 
 			# Hard error.
 			unless (defined $octet_count) {
@@ -101,7 +104,13 @@ role {
 
 1;
 
-__END__
+
+
+=pod
+
+=for :stopwords Rocco Caputo
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -109,10 +118,13 @@ Reflex::Role::Writing - add buffered non-blocking syswrite() to a class
 
 =head1 VERSION
 
-version 0.088
+This document describes version 0.090, released on July 30, 2011.
 
 =head1 SYNOPSIS
 
+TODO - Changed again.  It would be stellar if I could include a
+different bit of code as a synopsis or something, huh?
+
 	package OutputStreaming;
 	use Reflex::Role;
 
@@ -125,18 +137,18 @@ version 0.088
 	role {
 		my $p = shift;
 
-		my $h         = $p->handle();
+		my $att_handle         = $p->handle();
 		my $cb_error  = $p->cb_error();
 
 		with 'Reflex::Role::Writing' => {
-			handle        => $h,
+			handle        => $att_handle,
 			cb_error      => $p->cb_error(),
 			method_put    => $p->method_put(),
 			method_flush  => $p->method_flush(),
 		};
 
 		with 'Reflex::Role::Writable' => {
-			handle        => $h,
+			handle        => $att_handle,
 			cb_ready      => $p->method_flush(),
 		};
 
@@ -254,20 +266,126 @@ Reflex::Role::Streaming is an up-to-date example.
 
 =head1 SEE ALSO
 
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Reflex|Reflex>
+
+=item *
+
 L<Reflex>
+
+=item *
+
 L<Reflex::Role>
+
+=item *
+
 L<Reflex::Role::Writable>
+
+=item *
+
 L<Reflex::Role::Readable>
+
+=item *
+
 L<Reflex::Role::Streaming>
 
+=item *
+
 L<Reflex/ACKNOWLEDGEMENTS>
+
+=item *
+
 L<Reflex/ASSISTANCE>
+
+=item *
+
 L<Reflex/AUTHORS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/BUGS>
+
+=item *
+
 L<Reflex/CONTRIBUTORS>
+
+=item *
+
 L<Reflex/COPYRIGHT>
+
+=item *
+
 L<Reflex/LICENSE>
+
+=item *
+
 L<Reflex/TODO>
 
-=cut
\ No newline at end of file
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 AUTHOR
+
+Rocco Caputo <rcaputo@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Rocco Caputo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/Reflex/>.
+
+The development version lives at L<http://github.com/rcaputo/reflex>
+and may be cloned from L<git://github.com/rcaputo/reflex.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
+=cut
+
+
+__END__
+
